@@ -6,7 +6,7 @@ import click
 COMMON_OPTIONS = [
     click.option('--enable-standard-rules/--disable-standard-rules',
                  default=True,
-                 help='Allows for enabling/disabling the standard rule set ' +   # noqa: W504
+                 help='Allows for enabling/disabling the standard rule set ' +  # noqa: W504
                  'that ships with mc-nag.'),
     click.option('--custom-platform-rules-dir', '-C', multiple=True,
                  type=click.Path(exists=True), default=None,
@@ -14,8 +14,9 @@ COMMON_OPTIONS = [
                  'Allows multiple.')
 ]
 MAIN_OPTIONS = COMMON_OPTIONS + [
+    click.option('--rules', is_flag=True),
     click.option('--filepath', '-f', type=click.Path(exists=True),
-                 required=True),
+                 required=False),
     click.option('--output', '-o', default='text',
                  type=click.Choice(['text', 'json', 'yaml', 'none'],
                                    case_sensitive=False)),
@@ -26,8 +27,10 @@ MAIN_OPTIONS = COMMON_OPTIONS + [
 
 def add_click_options(options):
     """Decorate with Click options."""
+
     def _add_options(func):
         for option in reversed(options):
             func = option(func)
         return func
+
     return _add_options
