@@ -99,7 +99,7 @@ class BaseRule(metaclass=RequiredAttributeDefinitionMeta):
             'evaluate() method with logic to implement rule!'
         )
 
-    def __clean_tags(self, dirty_tags):
+    def __clean_tags(self, dirty_tags):  # pylint: disable=no-self-use
         """Sanitize tags for consistency.
 
         :return: A set data type of lowercase strings.
