@@ -49,7 +49,7 @@ class RuleEvaluator:
                 severity_counts[rule_object.severity] = 0
             severity_counts[rule_object.severity] += 1
 
-        return violations_by_rule, severity_counts
+        return violations_by_rule, severity_counts, self.rule_set
 
     def display_rules(self):
         """Output list of rules and rule IDs in given format.
