@@ -77,10 +77,11 @@ def test_rule_evaluator_passing_template(valid_template_model):
     rule_evaluator = RuleEvaluator(valid_template_model,
                                    'tests/rules/standard')
     rule_evaluator.rule_set = set([StandardRule])
-    violations_by_rule, violation_counts = rule_evaluator.evaluate_rules()
+    violations_by_rule, violation_counts, rules = rule_evaluator.evaluate_rules()
 
     assert not violations_by_rule
     assert not violation_counts
+    assert rules == {StandardRule}
 
 
 def test_rule_evaluator_failing_rule(invalid_template_model):
@@ -88,12 +89,13 @@ def test_rule_evaluator_failing_rule(invalid_template_model):
     rule_evaluator = RuleEvaluator(invalid_template_model,
                                    'tests/rules/custom')
     rule_evaluator.rule_set = set([CustomPlatformRule])
-    violations_by_rule, violation_counts = rule_evaluator.evaluate_rules()
+    violations_by_rule, violation_counts, rules = rule_evaluator.evaluate_rules()
 
     assert CustomPlatformRule in violations_by_rule
     assert len(violations_by_rule[CustomPlatformRule]) == 1
     assert RULE_WARNING in violation_counts
     assert violation_counts[RULE_WARNING] == 1
+    assert rules == {CustomPlatformRule}
 
 
 def test_rule_evaluator_bad_rule(invalid_template_model):
@@ -112,7 +114,7 @@ def test_rule_evaluator_bad_rule(invalid_template_model):
     rule_evaluator.rule_set = set([BadRule])
 
     with raises(NotImplementedError, match="'BadRule' must define"):
-        _, _ = rule_evaluator.evaluate_rules()
+        _, _, _ = rule_evaluator.evaluate_rules()
 
 
 def test_rule_evaluator_display_rules_no_dupes(capsys):
